
%{
#include "rumd/PairPotential.h"
  %}

%nodefaultctor Potential; // disable generation of wrapper for default constructor

class Potential
{
 public:
  void SetVerbose(bool vb);
  void SetID_String(const std::string& set_ID_String);
  std::string GetID_String() const { return ID_String; }
};


%nodefaultctor PairPotential; // disable generation of wrapper for default constructor

class PairPotential : public Potential
{
 public:
  void WritePotentials(SimulationBox* simBox);
  void SetNbListSkin( float skin );
  enum CutoffMethod {NS, SP, SF};
  void SetExclusionType( unsigned type0, unsigned type1 );
  void PrintExclusionList();
};


%pythoncode %{
  NoShift = PairPotential.NS
  ShiftedPotential = PairPotential.SP
  ShiftedForce = PairPotential.SF
%}


%feature ("autodoc","1") SetParams; // generate docstring for SetParams

// docstring for Pot_LJ_12_6
%feature("autodoc","Standard 12-6 Lennard-Jones (cut and shifted potential)
v(r) =  4 Epsilon ( (Sigma/r)^12 -    (Sigma/r)^6 ) - v_cut
s(r) = 48 Epsilon ( (Sigma/r)^14 - 0.5(Sigma/r)^8 )/Sigma^2 = -r^-1*dv/dr (F_ij = s * r_ij)") Pot_LJ_12_6;

class Pot_LJ_12_6 : public PairPotential
{
 public:
  Pot_LJ_12_6( CutoffMethod cutoff_method );
  void SetParams(unsigned int i, unsigned int j, float Sigma, float Epsilon, float Rcut);
};

%feature("autodoc","Generalized Lennard-Jones (cut and shifted potential)
v(r) =   Epsilon/(m -n) ( n*(Sigma/r)^m -  m*(Sigma/r)^n ) - v_cut
s(r) =  Epsilon ( (Sigma/r)^14 - 0.5(Sigma/r)^8 )/Sigma^2 = -r^-1*dv/dr (F_ij = s * r_ij)\n") Pot_gLJ_m_n; 


class Pot_gLJ_m_n : public PairPotential
{
 public:
  Pot_gLJ_m_n(float set_m, float set_n, CutoffMethod cutoff_method );
  void SetParams(unsigned int i, unsigned int j, float Sigma, float Epsilon, float Rcut);
};

%feature("autodoc","Standard 12-6 Lennard-Jones (cut and shifted potential)
with definition of Sigma from Hoang and Odagasaki
Sigma HO = 2^(1/6) Sigma LJ
v(r) =   Epsilon ( (Sigma/r)^12 -  2 *  (Sigma/r)^6 ) - v_cut
s(r) = 12 Epsilon ( (Sigma/r)^14 - (Sigma/r)^8 )/Sigma^2 = -r^-1*dv/dr (F_ij = s * r_ij)\n") Pot_LJ_12_6_NEW; 

class Pot_LJ_12_6_NEW : public PairPotential
{
 public:
  Pot_LJ_12_6_NEW( CutoffMethod cutoff_method);
  void SetParams(unsigned int i, unsigned int j, float Sigma, float Epsilon, float Rcut);
};


%feature("autodoc","12-6 Lennard-Jones plus Gaussian potential cut and shifted.
v(r) =  Epsilon ( (Sigma/r)^12 -  2(Sigma/r)^6 - Epsilon_0 (exp[-(r - r_0)^2 / (2 Sigma_0^2)] ) ) - v_cut
v(r) is a double well with second well located at r_0 with depth Epsilon_0.
s(r) = 48 Epsilon ( (Sigma/r)^14 - 0.5(Sigma/r)^8 )/Sigma^2 = -r^-1*dv/dr (F_ij = s * r_ij)") Pot_LJ_12_6_Gauss; 

class Pot_LJ_12_6_Gauss : public PairPotential
{
 public:
  Pot_LJ_12_6_Gauss( CutoffMethod cutoff_method);
  void SetParams(unsigned int i, unsigned int j, float Sigma, float Epsilon, float Rcut, float Sigma0, float Epsilon0, float r0);
};


%feature("autodoc","Gaussian core potential
v(r) = Epsilon * exp[-(r/Sigma)^2]
s(r) = ( 2 * Epsilon / Sigma^2 ) * exp[-(r/Sigma)^2] = -r^-1*dv/dr (F_ij = s * r_ij)") Pot_Gauss; 

class Pot_Gauss : public PairPotential
{
 public:
  Pot_Gauss( CutoffMethod cutoff_method );
  void SetParams(unsigned int i, unsigned int j, float Sigma, float Epsilon, float Rcut);
};

%feature("autodoc","\nBuckingham potential
v(r) = Epsilon{(6/(Alpha - 6))*exp[Alpha(1-r/rm)] - (Alpha/(Alpha -6))*(rm/r)**6}
s(r) = -r^-1*dv/dr = ((6*Alpha*Epsilon)/(Alpha - 6)){r^(-1)*exp[Alpha(1-r/rm)] - rm^(-6)*r^(-8)}
w(r) = s*r^2 = ((6*Alpha*Epsilon)/(Alpha - 6))*{r*exp[Alpha(1-r/rm)] - (rm/r)^6}") Pot_Buckingham; 

class Pot_Buckingham : public PairPotential
{
 public:
  Pot_Buckingham( CutoffMethod cutoff_method);
  void SetParams(unsigned int i, unsigned int j, float rm, float Alpha, float Epsilon, float Rcut);
};


%feature("autodoc","\nIPL potential, n=12. (cut and shifted potential)
v(r) =    Epsilon ( (Sigma/r)^12 ) - v_cut
s(r) = 12 Epsilon ( (Sigma/r)^14 )/Sigma^2 = -r^-1*dv/dr (F_ij = s * r_ij)\n") Pot_IPL_12; 

class Pot_IPL_12 : public PairPotential
{
 public:
  Pot_IPL_12( CutoffMethod cutoff_method ) ;
  void SetParams(unsigned int i, unsigned int j, float Sigma, float Epsilon, float Rcut);
};


%feature("autodoc","IPL potential, n=18. (cut and shifted potential)
v(r) =    Epsilon ( (Sigma/r)^18 ) - v_cut
s(r) = 18 Epsilon ( (Sigma/r)^20 )/Sigma^2 = -r^-1*dv/dr (F_ij = s * r_ij)\n") Pot_IPL_18; 

class Pot_IPL_18 : public PairPotential
{
 public:
  Pot_IPL_18( CutoffMethod cutoff_method );
  void SetParams(unsigned int i, unsigned int j, float Sigma, float Epsilon, float Rcut);
};

%feature("autodoc","\nIPL potential, abritrary exponent n. (cut and shifted potential)
v(r) =   Epsilon ( (Sigma/r)^n ) - v_cut
s(r) = n Epsilon ( (Sigma/r)^(n+2) )/Sigma^2 = -r^-1*dv/dr (F_ij = s * r_ij)\n") Pot_IPL_n; 

class Pot_IPL_n : public PairPotential
{
 public:
  Pot_IPL_n( float n, CutoffMethod cutoff_method );
  void SetParams(unsigned int i, unsigned int j, float Sigma, float Epsilon, float Rcut);
};

%feature("autodoc","Dzugutov potential") Pot_Dzugutov; 

class Pot_Dzugutov : public PairPotential
{
 public:
  Pot_Dzugutov();
  void SetParams(unsigned int i, unsigned int j, float a, float b, float c, float d, float A, float B);
};
