#ifndef CONFIGURATIONMETADATA_H
#define CONFIGURATIONMETADATA_H

#include <cstdio>
#include <cassert>
#include <cstdlib>

#include <string>
#include <map>

#include "rumd/rumd_base.h"

#include "rumd/LogLin.h"

// this class handles two kinds of metaData for configuration files
// (1) specific data in the comment line, such as the box-length (this is
// specfically needed for reading, not so much for writing since it is available
// to the sample class anyway)
// (2) which per-particle data is in the file (specifies as the "columns" entry 
// in the comment line)

class ConfigurationMetaData
{
public:
  ConfigurationMetaData():
    precision(6),
    rumd_conf_ioformat(0), // refers to a file, so could be different from the current rumd_conf_ioformat
    numTypes(1), // refers to a file
    timeStepIndex(0),
    numMolecules(0),
    L(),
    Ps(0.),
    Pv(0.),
    dt(0.),
    massOfType(),
    has_images(false),
    has_velocities(false),
    has_forces(false),
    has_pot_energies(false),
    has_virials(false),
    has_moleculeIndices(false),
    has_logLin(false),
    blockSize(0),
    logLin()
  {
    // might want to remove this and place the burden of initialization
    // on the calling function
    for(unsigned int cd = 0; cd < DIM; ++cd)
      L[cd] = 0.;
    for(unsigned int tdx = 0;tdx < MaxNumTypes; ++tdx)
      massOfType[tdx] = 1.;
  }
  // the function which parses the comment line for configuration files
  void ReadMetaData(char *commentLine, bool verbose);
  

  unsigned int precision;
  // might want to add a separate precision for energies/virials
  unsigned int rumd_conf_ioformat;
  unsigned int numTypes;
  unsigned int timeStepIndex;
  unsigned int numMolecules;
  float L[DIM];
  float Ps;
  float Pv;
  float dt;
  float massOfType[MaxNumTypes];
  bool has_images;
  bool has_velocities;
  bool has_forces;
  bool has_pot_energies;
  bool has_virials;
  bool has_moleculeIndices;
  bool has_logLin;
  unsigned int blockSize;
  LogLin logLin;
};


#endif // CONFIGURATIONMETADATA_H
